<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="br">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Dilemel</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">Skramm-leun</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">Diaporama</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">Ezporzhiañ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">Eilañ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">Sined</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Treiñ er memes tu hag an horolaj</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">Treiñ en tu enep eus an horolaj</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">Termeniñ evel paper-moger</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">Diskouez er merer restroù</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">Titouroù ar skeudenn</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">Adsevel</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Dizanvet</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Krouiñ</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Albom nevez</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Ha fellout a ra deoc&apos;h dilemel an albom-mañ?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Pod-lastez</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Emporzhiañ</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Pod-lastez</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Pe laoskit fotoioù amañ</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Emporzhiañ pep-tra</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Emporzhiañ davet:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Emporzhiañ</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Disk sistem</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Ac&apos;hubet eo an disk, n&apos;heller ket strinkañ anezhañ er-maez</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Mat eo</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Albom nevez</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Na ober van</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Albom</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Erlec&apos;hiañ</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ezporzhiañ</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Skeudennoù</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Teuliadoù</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pellgargadennoù</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Burev</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoioù</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Sonerezh</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Anv:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Enrollañ e-barzh:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Furmad:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kalite:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Diuzañ ar c&apos;havlec&apos;hioù</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Mat eo</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>N&apos;hall ket bezañ goullo anv ar restr</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>a zo anezhañ/anezhi endeo. Ha fellout a ra deoc&apos;h e vefe erlec&apos;hiet?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Lenner</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Disk %1 goullo</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 Enkriptet</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Live-son</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Ezporzhiañ ar fotoioù</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>O tilemel...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Oc&apos;h adsevel...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Titouroù diazez</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Munudoù</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Emporzhiañ</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Adenvel</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ezporzhiañ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Aparailh</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albomoù</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Albom nevez</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotoioù</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skramm-leun</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Skoazell</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Diskouez er merer restroù</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Eilañ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Termeniñ evel paper-moger</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Treiñ er memes tu hag an horolaj</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Treiñ en tu enep eus an horolaj</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Kent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Da-heul</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sined</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Disinedet</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Adenvel an albom</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Albom “%1” dilamet</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Ouzhpennet gant berzh da &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Emporzhiet gant berzh</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Emporzhiañ c&apos;hwitet</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ezporzhiañ c&apos;hwitet</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Ezporzhiet gant berzh</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>An holl skeudennoù</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Eurvezhioù</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albomoù</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Kuitaat ar skramm-leun/diaporama</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Diskouez ar berradurioù</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Gweled</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Diuzañ pep-tra</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoumañ</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Dizoumañ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Albom nevez</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pajenn gent</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pajenn war-draoñ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Arventennoù</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Oc&apos;h emporzhiañ...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Dilemel</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Doare</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Ment ar restr</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Mentoù</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Deiziad an dapadenn</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Deiziad ar c&apos;hemm</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mod tapadenn</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program an dapadenn</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Padelezh an dapadenn</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Digeriñ</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Hirded ar fokal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Digoret d&apos;ar maksimom</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mod muzuliañ</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balañs al livioù gwenn</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kempouezañ flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model ar mekanik foto</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model lentilh</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Spas al livioù</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Liketenn</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Disk sistem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Diuzañ</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Diziuzañ</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Emporzhiet e-barzh</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Adsevel</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotoioù</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoioù</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sined</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Treiñ en tu enep eus an horolaj</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Treiñ er memes tu hag an horolaj</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Oc&apos;h emporzhiañ...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Disoc&apos;h ebet d&apos;an enklask</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Disoc&apos;hoù an enklask</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Gweled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skramm-leun</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ezporzhiañ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sined</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Disinedet</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Treiñ er memes tu hag an horolaj</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Treiñ en tu enep eus an horolaj</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Diskouez er merer restroù</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Termeniñ evel paper-moger</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Eilañ</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Titouroù ar skeudenn</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Ouzhpennañ d&apos;an albom</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Dilemel diwar an albom</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Adsevel</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Albom nevez</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Moullañ</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">devezhioù</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Titouroù diazez</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Deiziad ar c&apos;hemm</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Doare</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Ment ar restr</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Deiziad an dapadenn</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
